Rendering

# 7 Rendering

`NanoCap` provides a 3D rendering and interaction interface using the `VTK` libraries and the associated widgets in `Qt`. This allows real time inspection of the structures that are being constructed or previously found structures loaded from the database. Current capabilities include the rendering of both dual and carbon lattices, the carbon-carbon bonds, the ring network and the dimensions of the current structure. These options are dynamic, with any changes to the appearance of the current structure changing in real time. To force changes to the points, bonds or rings use the options in the Calculations tab.

An example of the `NanoCap`rendering options and render window are shown in Fig. 12.

Figure 12: The `NanoCap` rendering options and the corresponding render window.

- 7.1 Schlegel View